Stan Math Library: Namespace Members

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Namespace List
- Namespace Members

- All
- Functions
- Variables
- Typedefs

- a
- b
- c
- d
- e
- f
- g
- h
- i
- j
- l
- m
- n
- o
- p
- q
- r
- s
- t
- u
- v
- w

Here is a list of all namespace members with links to the namespace documentation for each member:

### - l -

- lb_constrain() : stan::math
- lb_free() : stan::math
- lbeta() : stan::math
- length() : stan
- length_mvt() : stan
- lgamma() : stan::math
- lkj_corr_cholesky_log() : stan::math
- lkj_corr_cholesky_rng() : stan::math
- lkj_corr_log() : stan::math
- lkj_corr_rng() : stan::math
- lkj_cov_log() : stan::math
- lmgamma() : stan::math
- log() : stan::math
- log10() : stan::math
- log1m() : stan::math
- log1m_exp() : stan::math
- log1m_inv_logit() : stan::math
- log1p() : stan::math
- log1p_exp() : stan::math
- log2() : stan::math
- LOG_10 : stan::math
- LOG_2 : stan::math
- log_determinant() : stan::math
- log_determinant_ldlt() : stan::math
- log_determinant_spd() : stan::math
- log_diff_exp() : stan::math
- log_falling_factorial() : stan::math
- LOG_HALF : stan::math
- log_inv_logit() : stan::math
- log_inv_logit_diff() : stan::math
- log_mix() : stan::math
- log_mix_partial_helper() : stan::math
- LOG_PI : stan::math
- LOG_PI_OVER_FOUR : stan::math
- log_rising_factorial() : stan::math
- log_softmax() : stan::math
- LOG_SQRT_PI : stan::math
- log_sum_exp() : stan::math
- LOG_TWO : stan::math
- LOG_TWO_PI : stan::math
- LOG_ZERO : stan::math
- logical_and() : stan::math
- logical_eq() : stan::math
- logical_gt() : stan::math
- logical_gte() : stan::math
- logical_lt() : stan::math
- logical_lte() : stan::math
- logical_negation() : stan::math
- logical_neq() : stan::math
- logical_or() : stan::math
- logistic_ccdf_log() : stan::math
- logistic_cdf() : stan::math
- logistic_cdf_log() : stan::math
- logistic_log() : stan::math
- logistic_rng() : stan::math
- logit() : stan::math
- lognormal_ccdf_log() : stan::math
- lognormal_cdf() : stan::math
- lognormal_cdf_log() : stan::math
- lognormal_log() : stan::math
- lognormal_rng() : stan::math
- lub_constrain() : stan::math
- lub_free() : stan::math

[ Stan Home Page ] © 2011–2016, Stan Development Team.